@@ -1,9 +1,10 @@
 #ifndef __RJAVA_H__
 #define __RJAVA_H__
 
-#define RJAVA_VER 0x00030a /* rJava v0.3-10 */
+#define RJAVA_VER 0x000400 /* rJava v0.4-0 */
 
 /* important changes between versions:
+   0.4  - includes JRI
    0.3  - uses EXTPTR in jobj slot, adds finalizers
    0.2  - uses S4 classes
    0.1  - first public release */
